PinCodeEvents enum
Enum contains all events that can happen in PinCodeController. These events are used in stream. There are all types of events: configuration-related, actual usage, timeouts and others.
Values
- initializationCompleted → const PinCodeEvents
-
Initialization was completed.
- pinSet → const PinCodeEvents
-
PIN code was set.
- pinRemoved → const PinCodeEvents
-
PIN code was removed.
- biometricsSet → const PinCodeEvents
-
Biometrics was set.
- biometricsDisabled → const PinCodeEvents
-
Biometrics was removed.
- requestAgainSet → const PinCodeEvents
-
Request again configuration was set.
- requestAgainDisabled → const PinCodeEvents
-
Request again configuration was removed.
- skipPinSet → const PinCodeEvents
-
Skip pin configuration was set.
- skipPinDisabled → const PinCodeEvents
-
Skip pin configuration was removed.
- pinSuccessfullyTested → const PinCodeEvents
-
Pin code was tested successfully.
- wrongPinCodeTested → const PinCodeEvents
-
Pin code was tested unsuccessfully.
- biometricsSuccessfullyTested → const PinCodeEvents
-
Biometrics was tested successfully.
- biometricsFailedTested → const PinCodeEvents
-
Biometrics was tested unsuccessfully.
- timeoutStarted → const PinCodeEvents
-
Timeout was started.
- timeoutEnded → const PinCodeEvents
-
Timeout was ended.
- requestAgainCalled → const PinCodeEvents
-
Request again was called.
- requestAgainSkipped → const PinCodeEvents
-
Request again was skipped.
- allAttemptsWasted → const PinCodeEvents
-
All attempts were wasted.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PinCodeEvents> - A constant List of the values in this enum, in order of their declaration.